# Tissue-Background Segmentation
Tissue-background segmentation of histopathological whole-slide images. In this project we collected 100 + 8 whole-slide images (WSIs) for development ant testing of a fully-convolutional neural network (FCNN) that can distinguish  between tissue and backgound areas on the WSIs.

## Project details:
* **Name:** Tissue-background segmentation of histopathological whole-slide images
* **Date:** 2018-02-26
* **Responsible:** [Peter Bandi](http://www.diagnijmegen.nl/index.php/Person?name=P%C3%A9ter_B%C3%A1ndi), [Geert Litjens](http://www.diagnijmegen.nl/index.php/Person?name=Geert_Litjens)
* **Trac ticket:** [#7458](https://repos.diagnijmegen.nl/trac/ticket/7458)
* **Overleaf paper:** [5c013f01f6058b0c93942c95](https://www.overleaf.com/project/5c013f01f6058b0c93942c95)

## Building the docker
To build the docker image *create an empty directory and move into it.* The following bash commands will do the required steps:
* Clone the repository of this project.
* Copy the *Dockerfile* and the *accompanying bash shell scripts* to the current directory.
* Build the docker image, that is:
  * Based on a UoK pathology base docker.
  * Updates the ASAP to version 1.9.
  * Copies this project into the docker image.
  * Copies the 4 networks that were developed in this project.

```bash
git clone https://github.com/DIAGNijmegen/pathology-tissue-background-segmentation.git
cp pathology-tissue-background-segmentation/docker/* ./
docker build . --tag pathology-tissue-background-segmentation:latest
```

Note that the 3 network files: *fcnn_a.net, fcnn_b.net, fcnn_c.net,* and *fcnn_d.net* needs to be manually copied to the build directory before bulding the docker.

## Running the experiments
The project is summarized in a single Jupyter notebook. Run the docker in interactive mode to start the Jupyter notebook and expose the ports. Once it is running connect to the notebook with a browser, open the *notebook.ipynb* and follow the instructions to recreate the results that were reported in the paper.

```bash
docker run --publish-all --detach pathology-tissue-background-segmentation:latest
```

However, the previous command will neither expose the ports on our cluster that are necessary to connect to the Jupyter server, nor mount the directory of the input data as */input.* It is recommended to schedule an interactive session, with the build UoK docker with the following command.

```bash
~/c-submit --interactive \
           --require-gpu-mem=8G \
           --require-mem=64G \
           --require-cpus=40 \
           --require-diskspace=256G \
           --gpu-count=1 \
           --input-dir=/mnt/synology/pathology/projects/TissueBackground/data \
           user 7458 8 oni:11500/uoks/pathology-tissue-background-segmentation:latest 
```

Note that the data is not guaranteed to be at the configured *input-dir*. The specified path is the current location of the project. In case the project folder, it can be reproduced by executing the *prepare_data.sh* bash script that collects the complete data set from the mother archive.