"""
System-wide errors.
"""

from . import errorbase as dpterrorbase

#----------------------------------------------------------------------------------------------------

class DigitalPathologySystemError(dpterrorbase.DigitalPathologyError):
    """Error base class for all system errors."""

    def __init__(self, *args):
        """
        Initialize the object.

        Args:
            *args: Argument list.
        """

        # Initialize base class.
        #
        super().__init__(*args)

#----------------------------------------------------------------------------------------------------

class ProcessKilledError(DigitalPathologySystemError):
    """The process received SIGINT signal."""

    def __init__(self, signal_id, signal_name):
        """
        Initialize the object.

        Args:
            signal_id (int): Signal id.
            signal_name (str): Signal name.
        """

        # Initialize base class.
        #
        super().__init__('{name} ({id}) received.'.format(name=signal_name, id=signal_id))

        # Store custom data.
        #
        self.signal_id = signal_id
        self.signal_name = signal_name
