"""
This file contains class describing an image patch source.
"""

class PatchSource(object):
    """This class can store image path, image level list, mask path, mask pixel spacing data."""

    def __init__(self, image_path, mask_path, mask_spacing, stat_path, available_labels):
        """
        Initialize the object.

        Args:
            image_path (str): Path of the image file.
            mask_path (str, None): Path of the mask file.
            mask_spacing (float): Mask processing pixel spacing (micrometer).
            stat_path (str, None): Path of the stats file.
            available_labels (tuple): List of available labels in the mask to use.
        """

        # Initialize the base class.
        #
        super().__init__()

        # Initialize members.
        #
        self.image_path = image_path                     # Path of the image.
        self.mask_path = mask_path                       # Path of the mask to use with the image.
        self.mask_spacing = mask_spacing                 # Level of mask to use.
        self.stat_path = stat_path                       # Mask stat path.
        self.available_labels = tuple(available_labels)  # Labels to use.

    def __eq__(self, other):
        """
        Equals operator for comparing sources.

        Args:
            other (PatchSource): Other side of comparison.

        Returns:
            bool: True if the two objects describes the same data source, False otherwise.
        """

        return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Not-equals operator for comparing sources.

        Args:
            other (PatchSource): Other side of comparison.

        Returns:
            bool: True if the two objects does not describe the same data source, False otherwise.
        """

        return not (self == other)

    def __hash__(self):
        """
        Hash for comparing sources.

        Returns:
            int: Hash of this object.
        """

        return hash((self.image_path, self.mask_path, self.mask_spacing, self.stat_path) + self.available_labels)
