"""
This module contains a function that converts multi-resolution images to standard TIFF format.
"""

import os
import subprocess

#----------------------------------------------------------------------------------------------------

def convert_image(converter_path, source_path, target_path, logger=None):
    """
    Convert image with JPEG compression with 80% compression factor.

    Args:
        converter_path (str): Converter executable path.
        source_path (str): Source image path.
        target_path (str): Target image path.
        logger (logging.Logger, None): Logger object.

    Raises:
        ValueError: Conversion executable returns with a non-zero return code.
    """

    if logger:
        logger.info('Convert: {source} -> {target}'.format(source=source_path, target=target_path))

    # Execute conversion command.
    #
    extension = os.path.splitext(os.path.basename(source_path))[1].lower()
    if extension in ['.tif', '.tiff']:
        # The slide is already TIFF. Just rename it.
        #
        os.rename(source_path, target_path)
    else:
        # Convert the slide.
        #
        command = [converter_path, source_path, target_path, '--codec', 'JPEG', '--rate', '70']
        return_code = subprocess.call(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)

        if return_code != 0:
            raise ValueError('Conversion error.', return_code)
